@@ -61,15 +61,18 @@ public:
         std::vector<ThreadingStruct> & getGappedThreadingVector() { return gappedThreadingStructVector; }
         void createSpringsFromGappedThreading(BiopolymerClassContainer & myBiopolymerClassContainer);
         void addGappedThreading(const ThreadingStruct & threadingStruct, BiopolymerClassContainer & myBiopolymerClassContainer);
-        void addGappedThreading(String chain1, String chain2, double forceConstant, bool backboneOnly, BiopolymerClassContainer & myBiopolymerClassContainer);
+        void addGappedThreading(String chain1, String chain2, double forceConstant, bool backboneOnly, BiopolymerClassContainer & myBiopolymerClassContainer,double gapPenalty, String scoringScheme);
         void addGappedThreading(String chain1, ResidueID startResidue1,  ResidueID endResidue1,   String chain2, ResidueID startResidue2,  ResidueID endResidue2,  double forceConstant, bool backboneOnly,
-                                       BiopolymerClassContainer & myBiopolymerClassContainer);
+                                       BiopolymerClassContainer & myBiopolymerClassContainer,double gapPenalty, String scoringScheme);
         void deleteGappedThreading(int id);
         void updateGappedThreading(int id, const ThreadingStruct & threadingStruct, BiopolymerClassContainer & myBiopolymerClassContainer);
-        void updateGappedThreading(int id, String chain1, String chain2, double forceConstant, bool backboneOnly, BiopolymerClassContainer & myBiopolymerClassContainer);
+        void updateGappedThreading(int id, String chain1, String chain2, double forceConstant, bool backboneOnly, BiopolymerClassContainer & myBiopolymerClassContainer,double gapPenalty, String scoringScheme);
 
-        static ThreadingStruct createGappedThreading(String chain1, String chain2, double forceConstant, bool backboneOnly, BiopolymerClassContainer & myBiopolymerClassContainer);
-        static ThreadingStruct createGappedThreading(String chain1, ResidueID startResidue1,  ResidueID endResidue1, String chain2,  ResidueID startResidue2,  ResidueID endResidue2,  double forceConstant, bool backboneOnly, BiopolymerClassContainer & myBiopolymerClassContainer);
+        static ThreadingStruct createGappedThreading(String chain1, String chain2, double forceConstant, bool backboneOnly, BiopolymerClassContainer & myBiopolymerClassContainer1,  BiopolymerClassContainer & myBiopolymerClassContainer2,double gapPenalty, String scoringScheme );
+
+        static ThreadingStruct createGappedThreading(String chain1, String chain2, double forceConstant, bool backboneOnly, BiopolymerClassContainer & myBiopolymerClassContainer,double gapPenalty, String scoringScheme) {return createGappedThreading( chain1,  chain2,  forceConstant, backboneOnly,  myBiopolymerClassContainer,   myBiopolymerClassContainer, gapPenalty,  scoringScheme);}; // For backward compatibility. Just calls its two-BiopolymerClassContainer counterpart with both BiopolymerClassContainer's set to the same object.
+        static ThreadingStruct createGappedThreading(String chain1, ResidueID startResidue1,  ResidueID endResidue1, String chain2,  ResidueID startResidue2,  ResidueID endResidue2,  double forceConstant, bool backboneOnly, BiopolymerClassContainer & myBiopolymerClassContainer1,BiopolymerClassContainer & myBiopolymerClassContainer2,double gapPenalty, String myScoringScheme    ) ;
+        static ThreadingStruct createGappedThreading(String chain1, ResidueID startResidue1,  ResidueID endResidue1, String chain2,  ResidueID startResidue2,  ResidueID endResidue2,  double forceConstant, bool backboneOnly, BiopolymerClassContainer & myBiopolymerClassContainer,double gapPenalty, String scoringScheme) {return createGappedThreading(chain1, startResidue1,  endResidue1, chain2,  startResidue2,   endResidue2,  forceConstant, backboneOnly,  myBiopolymerClassContainer ,  myBiopolymerClassContainer, gapPenalty,  scoringScheme);}; // For backward compatibility. Just calls its two-BiopolymerClassContainer counterpart with both BiopolymerClassContainer's set to the same object.
         void printAllAlignmentStats(){for (int i = 0; i < threadingStructVector.size(); i++){threadingStructVector[i].printAlignmentStats();}}
 
 };
