@@ -17,15 +17,18 @@
 #include <iostream>
 #include <vector>
 #include <stdlib.h>// for MAX_PATH
+
+#include "MMB_config.h"
+
 #include "SimTKmolmodel.h"
 #include "PeriodicScrubber.h"  
 #include "BiopolymerClass.h"
 #include "ParameterReader.h"
 #include "PeriodicPdbAndEnergyWriter.h"
 #include "BiopolymerClassTwoTransformForces.h"
-//#ifdef BuildNtC
+#ifdef MMB_NTC_ENABLED
 #include "NtCForces.h"
-//#endif
+#endif // MMB_NTC_ENABLED
 #include "TetherForce.h"
 #include "Sterics.h" 
 #include "AddNASTForces.h"
@@ -182,10 +185,8 @@ public:
     */
     void initializeMoleculesAndBonds();
     void initializeMoleculesAndBonds(CompoundSystem & system, DuMMForceFieldSubsystem & dumm, SimbodyMatterSubsystem & matter);
-    #ifdef USE_OPENMM
     void setInterfaceMobilizers();
     void setInterfaceMobilizers(CompoundSystem & system, SimbodyMatterSubsystem & matter, State & state);
-    #endif
     void setMobilizers();
 
     /**
