@@ -11,6 +11,7 @@
 
 #ifndef Utils_H_
 #define Utils_H_                 
+#include <sys/stat.h>
 
 #include <cstring>
 #include <fstream>
@@ -83,8 +84,10 @@ public:
     //void validateReadable();
 };
 
+int MMB_EXPORT checkOrCreateDirectory(const std::string & directoryPath);
 int MMB_EXPORT myMkdir(const std::string & directoryPath);
 int MMB_EXPORT myChdir(const std::string & directoryPath);
+int MMB_EXPORT mySystemCall(const std::string & command);
 
 enum class CopyFileResult {
     Success,
@@ -118,6 +121,7 @@ inline double   myAtoF(  map<const String,double> myUserVariables,  const char*
     }
     double leptonResult = Lepton::Parser::parse(std::string(value)).evaluate(leptonFormatUserVariables);
     MMBLOG_FILE_FUNC_LINE(INFO, " Lepton evaluation = >"<< leptonResult<<"< "<<std::endl);
+    if (isnan(leptonResult)) MMBLOG_FILE_FUNC_LINE(CRITICAL, "The provided string >"<<value <<"< Evaluates to NaN! "<<endl);
     return leptonResult; // if Lepton_USAGE is defined, then we return here and the rest of the procedure is not used. 
 #endif
     // If  LEPTON_ENABLED is NOT defined, then we parse the formula the old dumb way, as follows.
@@ -190,6 +194,7 @@ inline double   myAtoF(  map<const String,double> myUserVariables,  const char*
             }
         }
         //MMBLOG_FILE_FUNC_LINE(endl;
+	if (isnan(baseDouble)) MMBLOG_FILE_FUNC_LINE(CRITICAL, "The provided string >"<<value<<"< Evaluates to NaN! "<<endl);
         return baseDouble;
     }
 
@@ -262,19 +267,6 @@ namespace { // unnamed namespace means it is translation unit local.
 std::string   trim(const std::string& str,
                  const std::string& whitespace = " \t\n\r"
                  );
-/*
-{ 
-    const auto strBegin = str.find_first_not_of(whitespace);
-    if (strBegin == std::string::npos)
-        return ""; // no content
-
-    const auto strEnd = str.find_last_not_of(whitespace);
-    const auto strRange = strEnd - strBegin + 1;
-
-    return str.substr(strBegin, strRange);
-    //return std::string ("hello");
-}
-*/
 
 bool MMB_EXPORT vectorCompare(String myString, vector<String> & comparisonStringVector) ;
 
@@ -318,7 +310,7 @@ public:
         char insertionCode;
         int residueNumber;
         int stringLength = inputString.length();
-        char endChar = *(inputString.substr(stringLength-1, 1)).c_str();
+        //char endChar = *(inputString.substr(stringLength-1, 1)).c_str();
         //if (validate)
             for (int i = 1; i < stringLength-1 ; i++) { // check all characters except first and last.
                 if (
@@ -663,50 +655,17 @@ class Interface {
                double         getDepth() {return Depth;};
                void print (){
                    MMBLOG_FILE_LINE(INFO, "For interface, printing reference chains : "<<std::endl);
-                   for (int i = 0; i < Chains.size(); i ++) {
+                   for (unsigned int i = 0; i < Chains.size(); i ++) {
                         MMBLOG_FILE_LINE(INFO, ">"<<Chains[i]<<"<, "<<std::endl);
                    };
                    MMBLOG_FILE_LINE(INFO, " Partner chains : "<<std::endl);
-                   for (int i = 0; i < Chains.size(); i ++) {
+                   for (unsigned int i = 0; i < Chains.size(); i ++) {
                         MMBLOG_FILE_LINE(INFO, ">" << PartnerChains[i]<<"<, "<<std::endl);
                    }
                    MMBLOG_FILE_LINE(INFO, " Depth : "<<Depth<<std::endl);
                };
 };
 
-/*
-
-struct MobilizerInterface {
-               vector<String> Chains ;
-               vector<String> PartnerChains ;
-               double    Depth       ;
-               String MobilizerString;
-               
-};
-
-class MobilizerInterfaceContainer    { 
-    private:
-        vector <MobilizerInterface> interfaceVector;
-     public:
-                void clear() {interfaceVector.clear() ;};
-                MobilizerInterfaceContainer() {clear() ;};
-        MobilizerInterface getMobilizerInterface(int interfaceIndex) {return interfaceVector[interfaceIndex];};
-        vector<String> getChains(int interfaceIndex) {return getMobilizerInterface(interfaceIndex).Chains;};
-        double getDepth(int interfaceIndex) {return interfaceVector[interfaceIndex].Depth;};
-        String getMobilizerString(int interfaceIndex) {return interfaceVector[interfaceIndex].MobilizerString;};
-        void addInterface(String myChain, double myDepth ,  String myMobilizerString){MobilizerInterface myInterface; myInterface.Chains.push_back( myChain);  myInterface.Depth = myDepth; myInterface.MobilizerString = myMobilizerString; interfaceVector.push_back(myInterface); };
-        void addInterface(vector<String> myChains, double myDepth ,  String myMobilizerString){MobilizerInterface myInterface; 
-                        myInterface.Chains.clear(); myInterface.PartnerChains.clear();
-            for (int i = 0; i < myChains.size(); i++) {myInterface.Chains.push_back( myChains[i]);}  myInterface.Depth = myDepth; myInterface.MobilizerString = myMobilizerString; interfaceVector.push_back(myInterface); };
-        void addInterface(vector<String> myChains,vector<String> partnerChains,  double myDepth ,  String myMobilizerString){MobilizerInterface myInterface; 
-                        myInterface.Chains.clear(); myInterface.PartnerChains.clear();
-            for (int i = 0; i < myChains.size(); i++) {myInterface.Chains.push_back( myChains[i]);}  
-            for (int i = 0; i < partnerChains.size(); i++) {myInterface.PartnerChains.push_back( partnerChains[i]);}  
-                        myInterface.Depth = myDepth; myInterface.MobilizerString = myMobilizerString; interfaceVector.push_back(myInterface); };
-        MobilizerInterface getInterface(int interfaceIndex) {return  interfaceVector[interfaceIndex];};
-        int numInterfaces() {return interfaceVector.size();};
-};
-*/
 class ResidueStretch   {
     private:
                 SimTK::String chain          ;
@@ -736,6 +695,7 @@ class ResidueStretch   {
 
                 ResidueStretch(const SimTK::String & myChain, const ResidueID & myStartResidue, const ResidueID & myEndResidue) { 
                     chain = myChain; startResidue = myStartResidue; endResidue= myEndResidue;
+		    printStretch();
                 }
 
                 ResidueStretch(const SimTK::String & myChain, const ResidueID & myResidue)
@@ -1281,17 +1241,18 @@ struct WaterDropletAboutResidueStruct {
 };
 
 class MMBAtomInfo {
+    private:
+        String chain;
+        ResidueID residueID;
+        ResidueInfo::Index  residueIndex;
+        String atomName;
     public:
         MobilizedBody mobilizedBody;
         MobilizedBodyIndex mobilizedBodyIndex;
         Compound::AtomIndex compoundAtomIndex;
-        String atomName;
         double  mass;
         int  atomicNumber;
         openmmVecType position;
-        ResidueID residueID;
-        ResidueInfo::Index  residueIndex;
-        String chain;
         double partialCharge;
         std::vector<MMBAtomInfo*> neighbors;
         //ChargedAtomType chargedAtomType;
@@ -1306,16 +1267,16 @@ class MMBAtomInfo {
         MMBAtomInfo(){};
 
         MMBAtomInfo(String myChain, ResidueID myResidueID, String myAtomName) :
-            atomName(std::move(myAtomName)),
             chain(std::move(myChain)),
-            residueID(std::move(myResidueID))
+            residueID(std::move(myResidueID)),
+            atomName(std::move(myAtomName))
         {}
 
         MMBAtomInfo(String myChain, ResidueID myResidueID, ResidueInfo::Index myResidueIndex, String myAtomName) :
-            atomName(std::move(myAtomName)),
             chain(std::move(myChain)),
             residueID(std::move(myResidueID)),
-            residueIndex(std::move(myResidueIndex))
+            residueIndex(std::move(myResidueIndex)),
+            atomName(std::move(myAtomName))
         {}
 
         bool operator == (MMBAtomInfo & a){
@@ -1376,13 +1337,13 @@ class InterfaceContainer    {
             {Interface myInterface; myInterface.Chains.push_back( myChain);  myInterface.Depth = myDepth; myInterface.MobilizerString = myMobilizerString; interfaceVector.push_back(myInterface); };
         void addInterface(vector<String> myChains, double myDepth = 0.0 ,  String myMobilizerString = "NONE"){Interface myInterface; 
                         myInterface.Chains.clear(); myInterface.PartnerChains.clear();
-            for (int i = 0; i < myChains.size(); i++) {myInterface.Chains.push_back( myChains[i]);}  myInterface.Depth = myDepth; myInterface.MobilizerString = myMobilizerString; interfaceVector.push_back(myInterface); };
+            for (unsigned int i = 0; i < myChains.size(); i++) {myInterface.Chains.push_back( myChains[i]);}  myInterface.Depth = myDepth; myInterface.MobilizerString = myMobilizerString; interfaceVector.push_back(myInterface); };
         void addInterface(vector<String> myChains,vector<String> partnerChains,  double myDepth ,  String myMobilizerString = "NONE");
         vector<TwoAtomClass> retrieveCloseContactPairs(vector<MMBAtomInfo> & concatenatedAtomInfoVector );
         Interface getInterface(int interfaceIndex) {return  interfaceVector[interfaceIndex];};
-        int numInterfaces() {return interfaceVector.size();};
+        unsigned int numInterfaces() {return interfaceVector.size();};
         void print(){
-            for (int i = 0 ; i < numInterfaces(); i++){
+            for (unsigned int i = 0 ; i < numInterfaces(); i++){
                  getInterface(i).print();
             } 
         };
