@@ -176,10 +176,10 @@ void MobilizerContainer::addMobilizerDomainsInterfacesToVector(const vector<Mobi
         unsigned int id1 = neighborList[j].first;
         unsigned int id2 = neighborList[j].second;
 
-        String chain1 = atomInfoVector[id1].chain;
-        ResidueID res1 = atomInfoVector[id1].residueID;
-        String chain2 = atomInfoVector[id2].chain;
-        ResidueID res2 = atomInfoVector[id2].residueID;
+        String chain1 = atomInfoVector[id1].getChain();
+        ResidueID res1 = atomInfoVector[id1].getResidueID();
+        String chain2 = atomInfoVector[id2].getChain();
+        ResidueID res2 = atomInfoVector[id2].getResidueID();
 
         double dist = atomInfoVector[id1].distance(atomInfoVector[id2]);
 
