@@ -525,11 +525,11 @@ void ConstrainedDynamics::createMultibodyTree(CompoundSystem & system, State & s
         String currentChain = String(system.getCompound(c).getPdbChainId());
         if (_parameterReader->myBiopolymerClassContainer.hasChainID(currentChain)){
             String tempMobilizerType =  _parameterReader->myBiopolymerClassContainer.updBiopolymerClass(currentChain).getFirstResidueMobilizerType();
-            MMBLOG_FILE_FUNC_LINE(INFO, "Attaching biopolymer chain "<<currentChain<<" using mobilizer type = "<<tempMobilizerType<<endl);
+            MMBLOG_FILE_FUNC_LINE(DEBUG, "Attaching biopolymer chain "<<currentChain<<" using mobilizer type = "<<tempMobilizerType<<endl);
             system.modelOneCompound(c,tempMobilizerType  );
         } else {
             String tempMobilizerType ("Free");
-            MMBLOG_FILE_FUNC_LINE(INFO, "Attaching non-biopolymer chain "<<currentChain<<" using mobilizer type = "<<tempMobilizerType<<endl);
+            MMBLOG_FILE_FUNC_LINE(DEBUG, "Attaching non-biopolymer chain "<<currentChain<<" using mobilizer type = "<<tempMobilizerType<<endl);
             system.modelOneCompound(c, tempMobilizerType );  // for non-biopolymers, use the default behavior, which is for root atom to be connected with a Free mobilizer.
         }
     }
@@ -706,8 +706,13 @@ void ConstrainedDynamics::initializeCustomForcesConstraints(){
        ((_parameterReader->includeNonBondAtomInBiopolymerVector.size() > 0) ||
     (_parameterReader->physicsContainer.getNumResidueStretches() /*includeAllNonBondAtomsInResidueVector.size()*/ > 0) ||
         (_parameterReader->includeAllResiduesWithinVector.size() > 0)) ;
+    bool myNonBondedOn = 
+    ((_parameterReader->globalCoulombScaleFactor >0) ||
+     (_parameterReader->globalVdwScaleFactor > 0));
  
+    //if (myPhysicsWhereYouWantItActive || (!(myNonBondedOn))) {
     if (myPhysicsWhereYouWantItActive) {
+        //MMBLOG_FILE_FUNC_LINE(INFO, "Detected that myPhysicsWhereYouWantItActive = "<<myPhysicsWhereYouWantItActive<<" and myNonBondedOn = "<<myNonBondedOn<<". If the former is 1 OR the latter is 0, then we need to clear the DuMM includedNonbondAtomList . We do that now."<<endl);
         MMBLOG_FILE_FUNC_LINE(INFO, "physicsWhereYouWantIt now has included : "<< _dumm.getNumIncludedAtoms () <<" atoms. Clearing list .."<<endl);
         _dumm.clearIncludedNonbondAtomList();
         MMBLOG_FILE_FUNC_LINE(INFO, "system.realizeTopology() "<<endl);
@@ -755,14 +760,15 @@ void ConstrainedDynamics::initializeCustomForcesConstraints(){
         _parameterReader->myBiopolymerClassContainer.printAllIncludedResidues ( _parameterReader->physicsContainer.getResidueStretchVector());   //includeAllNonBondAtomsInResidueVector);
     }
     //MMBLOG_FILE_FUNC_LINE(INFO, "_parameterReader->includeAllResiduesWithinVector.size() = "<<_parameterReader->includeAllResiduesWithinVector.size() << endl);
-    bool myNonBondedOn = 
-    ((_parameterReader->globalCoulombScaleFactor >0) ||
-     (_parameterReader->globalVdwScaleFactor > 0));
+
+    //bool myNonBondedOn = 
+    //((_parameterReader->globalCoulombScaleFactor >0) ||
+    // (_parameterReader->globalVdwScaleFactor > 0));
     MMBLOG_FILE_FUNC_LINE(INFO, "You have Coulomb and/or VdW forces : "<<myNonBondedOn<<" and some sort of PhysicsWhereYouWantIt : "<<myPhysicsWhereYouWantItActive<<endl);
-    if (    myPhysicsWhereYouWantItActive && myNonBondedOn )
+    if (myPhysicsWhereYouWantItActive && myNonBondedOn)
     {
         MMBLOG_FILE_FUNC_LINE(INFO, "This is fine!"<<endl);
-    } else if (myPhysicsWhereYouWantItActive && (!( myNonBondedOn)) ) 
+    } else if (myPhysicsWhereYouWantItActive && (!( myNonBondedOn))) 
     {
         MMBLOG_FILE_FUNC_LINE(CRITICAL, "You turned on Physics Where You Want It but don't have VdW or electrostatic interactions turned on!"<<endl);
     } else if ((!(myPhysicsWhereYouWantItActive)) && myNonBondedOn) 
@@ -787,7 +793,14 @@ void ConstrainedDynamics::initializeCustomForcesConstraints(){
 
     ////////////// Reading included monoAtoms (e.g. ions) //////////////
     MMBLOG_FILE_FUNC_LINE(INFO, "About to read monoAtoms, physicsWhereYouWantIt up to now has included : "<< _dumm.getNumIncludedAtoms () <<" atoms. "<<endl);
-    _parameterReader->myMonoAtomsContainer.includeAllAtoms(_dumm);
+    //MMBLOG_FILE_FUNC_LINE(INFO, "Detected myNonBondedOn = "<<myNonBondedOn<<endl);
+    if ( myNonBondedOn){
+        MMBLOG_FILE_FUNC_LINE(INFO, "As myNonBondedOn = "<<myNonBondedOn<< " is 1, we are adding the monoAtoms to DuMM's included atom list"<<endl);
+        MMBLOG_FILE_FUNC_LINE(INFO, "About to read monoAtoms, physicsWhereYouWantIt up to now has included : "<< _dumm.getNumIncludedAtoms () <<" atoms. "<<endl);
+        _parameterReader->myMonoAtomsContainer.includeAllAtoms(_dumm);}
+    else {
+        MMBLOG_FILE_FUNC_LINE(INFO, "As myNonBondedOn = "<<myNonBondedOn<< " is 0, we are NOT adding the monoAtoms to DuMM's included atom list"<<endl);
+    }
     MMBLOG_FILE_FUNC_LINE(INFO, "system.realizeTopology() "<<endl);
     _state = _system.realizeTopology();
     ////////////// Reading moleculeClassContainer //////////////
@@ -1011,7 +1024,7 @@ void ConstrainedDynamics::runAllSteps() {
 	_system.realize(_state,Stage::Dynamics);
         MMBLOG_FILE_FUNC_LINE(DEBUG, " " << endl);
 	for (int i = 0;  i < _forces.getNumForces(); i++){
-            MMBLOG_FILE_FUNC_LINE(INFO, " Force "<<i<<" contributes potential energy = "<<	_forces.getForce(ForceIndex(i)).calcPotentialEnergyContribution(_state)<<endl); 
+            MMBLOG_FILE_FUNC_LINE(INFO, " Force "<<i<<" of "<< _forces.getNumForces() <<" contributes potential energy = "<<	_forces.getForce(ForceIndex(i)).calcPotentialEnergyContribution(_state)<<endl); 
 	}
         MMBLOG_FILE_FUNC_LINE(DEBUG, "Just did a zero time simulation" << endl);
         //MMBLOG_FILE_FUNC_LINE(CRITICAL, "Cannot run more steps" << endl);
