@@ -88,23 +88,31 @@ bool hasAccessRight(LPCSTR path, DWORD genericAccessRights) {
 
     DWORD len = 0;
     if (GetFileSecurityA(path, OWNER_SECURITY_INFORMATION | GROUP_SECURITY_INFORMATION | DACL_SECURITY_INFORMATION, NULL, NULL, &len) == FALSE) {
-        MMBLOG_FILE_FUNC_LINE(CRITICAL, "Failed to get security information for file " << path << std::endl);
+        //MMBLOG_FILE_FUNC_LINE(CRITICAL, "Failed to get security information for file " << path << std::endl);
+	std::cout<<__FILE__<<":"<<__LINE__<<" Failed to get security information for file " << path << std::endl;
+	exit(1);
     }
 
     SecurityDescriptorWrapper sd{ len };
     if (GetFileSecurityA(path, OWNER_SECURITY_INFORMATION | GROUP_SECURITY_INFORMATION | DACL_SECURITY_INFORMATION, sd.get(), len, &len) == FALSE) {
-        MMBLOG_FILE_FUNC_LINE(CRITICAL, "Failed to get security information for file " << path << std::endl);
+        //MMBLOG_FILE_FUNC_LINE(CRITICAL, "Failed to get security information for file " << path << std::endl);
+	std::cout<<__FILE__<<":"<<__LINE__<<" Failed to get security information for file " << path << std::endl;
+	exit(1);
     }
 
     HANDLE hToken = NULL;
     HANDLE hImpersonatedToken = NULL;
     if (OpenProcessToken(GetCurrentProcess(), TOKEN_IMPERSONATE | TOKEN_QUERY | TOKEN_DUPLICATE | STANDARD_RIGHTS_READ, &hToken) == FALSE) {
-        MMBLOG_FILE_FUNC_LINE(CRITICAL, "Failed to get security information for file " << path << std::endl);
+        //MMBLOG_FILE_FUNC_LINE(CRITICAL, "Failed to get security information for file " << path << std::endl);
+	std::cout<<__FILE__<<":"<<__LINE__<<" Failed to get security information for file " << path << std::endl;
+	exit(1);
     }
 
     if (DuplicateToken(hToken, SecurityImpersonation, &hImpersonatedToken) == FALSE) {
         CloseHandle(hToken);
-        MMBLOG_FILE_FUNC_LINE(CRITICAL, "Failed to get security information for file " << path << std::endl);
+        //MMBLOG_FILE_FUNC_LINE(CRITICAL, "Failed to get security information for file " << path << std::endl);
+	std::cout<<__FILE__<<":"<<__LINE__<<" Failed to get security information for file " << path << std::endl;
+	exit(1);
     }
 
     GENERIC_MAPPING mapping = { 0xFFFFFFFF };
@@ -186,6 +194,46 @@ std::wstring unicodeFullPath(const std::string &path) {
 
 #endif // _WINDOWS
 
+// This function checks that a given directory exists. If it does not exist, myMkdir is called to create it. Then we confirm that the directory complies with:
+// path owner is the same as the process uid.
+// owner's permission on path are rwx.
+// If those two conditions are not met, the program exits.
+int checkOrCreateDirectory(const std::string & directoryPath) {
+    struct stat st;
+    if (stat(directoryPath.c_str(), &st) != 0) { // calling this stat constructor tells stat which path we are using.
+        std::cout<<__FILE__<<":"<<__LINE__<<" stat failed! But we do not give up yet, will try to create the directory."<<std::endl;
+        myMkdir(directoryPath);
+        std::cout<<__FILE__<<":"<<__LINE__<<" Done calling myMkdir("<<directoryPath<<");"<<std::endl;
+        //exit(1);
+    }
+    std::cout<<__FILE__<<":"<<__LINE__<<" Checking directory "<<directoryPath<<" ... st.st_mode = " << st.st_mode << " S_IFDIR = "<< S_IFDIR<< " "<<std::endl;
+    if (S_IFDIR == 16384){
+        std::cout<<__FILE__<<":"<<__LINE__<<"  S_IFDIR = "<< S_IFDIR << " equals 16384, or 40000 in octal. So it is a directory as we require."<<std::endl;
+    } else if (S_IFDIR == -1){
+        std::cout<<__FILE__<<":"<<__LINE__<<"  S_IFDIR = "<< S_IFDIR << " indicating it does not exist. We will create it now."<<std::endl;
+        myMkdir(directoryPath);
+    } else {
+        std::cout<<__FILE__<<":"<<__LINE__<<"  S_IFDIR = "<< S_IFDIR << " indicates a problem, we were expecting a directory here."<<std::endl;
+        exit(1);
+    }
+    // myMkdir checks for read and write access. So no need for this here now.
+    /*
+    std::cout<<__FILE__<<":"<<__LINE__<<" Comparing the path owner st_uid (user id) of "<<st.st_uid<<" with process uid of "<<geteuid()<<std::endl;
+    if (st.st_uid == geteuid()){
+        std::cout<<__FILE__<<":"<<__LINE__<<" Path owner matches process uid. All good."<<std::endl;
+    } else {
+        std::cout<<__FILE__<<":"<<__LINE__<<" Path owner does NOT match process uid. Exiting now.  "<<std::endl; exit(1);
+    }
+    mode_t permissions = st.st_mode & 0700; // leading 0 means this is octal number
+    std::cout<<__FILE__<<":"<<__LINE__<<" Masking all but the owner digit tells us the path has permissions : "<< std::oct <<permissions << std::dec        <<std::endl; // set back to decimal later to avoid confusion.
+    if (permissions == 0700){
+        std::cout<<__FILE__<<":"<<__LINE__<<" Evidently we have rwx permissions. All is good"<<std::endl;
+    } else {
+        std::cout<<__FILE__<<":"<<__LINE__<<" Evidently we do NOT have rwx permissions. Exiting now."<<std::endl; exit(1);
+    }*/
+    return 1;
+}
+
 int myMkdir(const std::string & directoryPath) {
 #ifdef _WINDOWS
     MMBLOG_FILE_FUNC_LINE(INFO, " You are asking to create the directory  " << directoryPath << std::endl);
@@ -204,6 +252,11 @@ int myMkdir(const std::string & directoryPath) {
         CloseHandle(hDir);
         return 1;
     }
+    if (!hasReadAccess(directoryPath.c_str())) {
+        MMBLOG_FILE_FUNC_LINE(CRITICAL, " Heads up! Found that we do NOT have read access to a directory called " << directoryPath << "  " << std::endl);
+        CloseHandle(hDir);
+        return 1;
+    }
 
     return 0;
 #else
@@ -215,21 +268,28 @@ int myMkdir(const std::string & directoryPath) {
         if (-1 == dir_err)
         {
             printf("Error creating directory!n");
-            MMBLOG_FILE_FUNC_LINE(INFO, " Failed to  create directory "<<directoryPath<<"  " <<std::endl);
+            MMBLOG_FILE_FUNC_LINE(CRITICAL, " Failed to  create directory "<<directoryPath<<"  " <<std::endl);
             exit(1);
         } else if (0 == dir_err) {
             MMBLOG_FILE_FUNC_LINE(INFO, " Successfully created directory "<<directoryPath<<" " <<std::endl);
         } else {
-            MMBLOG_FILE_FUNC_LINE(INFO, " An unexpected error occurred when creating the directory "<<directoryPath<<" " <<std::endl);
+            MMBLOG_FILE_FUNC_LINE(CRITICAL, " An unexpected error occurred when creating the directory "<<directoryPath<<" " <<std::endl);
+            exit(1);
         }
     }
     if (access((directoryPath ).c_str(), R_OK) == 0) {
         MMBLOG_FILE_FUNC_LINE(INFO, " Found that we have read access to a directory called "<< directoryPath   <<" . So far so good."<<std::endl);
-        return 0;
     } else {
         MMBLOG_FILE_FUNC_LINE(CRITICAL, " Heads up! Found that we do NOT have read access to a directory called "<<  directoryPath  <<"  "<<std::endl);
-        return 1;
+        //return 1;
     }
+    if (access((directoryPath ).c_str(), W_OK) == 0) {
+        MMBLOG_FILE_FUNC_LINE(INFO, " Found that we have write access to a directory called "<< directoryPath   <<" . So far so good."<<std::endl);
+    } else {
+        MMBLOG_FILE_FUNC_LINE(CRITICAL, " Heads up! Found that we do NOT have write access to a directory called "<<  directoryPath  <<"  "<<std::endl);
+        //return 1;
+    }
+    return 0;
 #endif // _WINDOWS
 }
 
@@ -251,6 +311,22 @@ int myChdir(const std::string & directoryPath) {
     }
 #endif // _WINDOWS
 }
+int mySystemCall(const std::string & command) {
+     int systemCallReturnValue = -11111;
+     std::cout<<__FILE__<<":"<<__LINE__<<" issuing system call : >"<<command<<"< "<<std::endl;
+     systemCallReturnValue = system(command.c_str());
+     std::cout<<__FILE__<<":"<<__LINE__<<" Command returned : >"<<systemCallReturnValue<<"< "<<std::endl;
+     if (systemCallReturnValue){
+         //MMBLOG_FILE_FUNC_LINE(CRITICAL, " System call returned a nonzero value. Exiting now.  "  << std::endl);
+	 //When exported, the MMBLOG_FILE_FUNC_LINE does not work properly.
+	 std::cout<<__FILE__<<":"<<__LINE__<<" System call returned a nonzero value. Exiting now.  "  << std::endl;
+	 exit(1);
+     } else {
+	 std::cout<<__FILE__<<":"<<__LINE__<<" System call successful.   "  << std::endl;
+     }
+     return systemCallReturnValue;
+
+}
 
 /* Copy file function variants */
 #ifdef _WINDOWS
@@ -264,14 +340,15 @@ CopyFileResult mmbCopyFile(const std::string &sourceFileName, const std::string
         if (!CopyFileW(src.c_str(), dst.c_str(), FALSE)) {
             auto err = GetLastError();
             if (err == ERROR_DISK_FULL) {
+                MMBLOG_PLAIN(CRITICAL, " Disk full error while copying a file: " << getErrorString(err) << "\n");
                 return CopyFileResult::No_Space;
             }
-            MMBLOG_PLAIN(WARNING, "IO error while copying a file: " << getErrorString(err) << "\n");
+            MMBLOG_PLAIN(CRITICAL, "IO error while copying a file: " << getErrorString(err) << "\n");
             return CopyFileResult::Io_Error;
         }
         return CopyFileResult::Success;
     } catch (const std::runtime_error &ex) {
-        MMBLOG_PLAIN(WARNING, ex.what() << "\n");
+        MMBLOG_PLAIN(CRITICAL, ex.what() << "\n");
         return CopyFileResult::Io_Error;
     }
 }
@@ -633,7 +710,7 @@ void closingMessage() {
     //std::cout<<__FILE__<<":"<<__LINE__<<" By bank transfer to IBAN: SE0750000000053680279418 , SWIFT: ESSESESS "<<std::endl;
     std::cout<<__FILE__<<":"<<__LINE__<<" Industrial and other inquiries: samuel.flores@scilifelab.se "<<std::endl;
     std::cout<<__FILE__<<":"<<__LINE__<<std::endl;
-};
+}
 
 CheckFile::CheckFile(const String & myFileName){
     fileName = myFileName;
@@ -713,7 +790,7 @@ bool vectorCompare(String myString, vector<String> & comparisonStringVector) {
         //cout<<endl;
     }
     return false; // If no String in comparisonStringVector is the same as myString
-};
+}
 
 BondMobility::Mobility stringToBondMobility(String bondMobilityString) {
        String myBondMobilityString =   bondMobilityString;
@@ -757,7 +834,7 @@ void InterfaceContainer::addInterface(vector<String> myChains,vector<String> par
     }
     myInterface.MobilizerString = myMobilizerString; 
     interfaceVector.push_back(myInterface); 
-};
+}
 
 
 vector<TwoAtomClass> InterfaceContainer::retrieveCloseContactPairs(vector<MMBAtomInfo> & concatenatedAtomInfoVector ){
@@ -774,7 +851,7 @@ vector<TwoAtomClass> InterfaceContainer::retrieveCloseContactPairs(vector<MMBAto
         }
 
         MMBLOG_FILE_FUNC_LINE(INFO, " neighborList size is : "<<neighborList.size()<<endl);
-        for (int h = 0 ; h < numInterfaces(); h++ ){ // loop through interfaceContainer interfaces ..
+        for (unsigned int h = 0 ; h < numInterfaces(); h++ ){ // loop through interfaceContainer interfaces ..
             vector<String> referenceChains = getInterface(h).getChains();  
             vector<String> partnerChains = getInterface(h).getPartnerChains();  
             double         radius        = getInterface(h).getDepth();  
@@ -783,23 +860,23 @@ vector<TwoAtomClass> InterfaceContainer::retrieveCloseContactPairs(vector<MMBAto
             cout<<__FILE__<<":"<<__LINE__<<endl;
             computeNeighborListVoxelHash(neighborList, particleList.size() , particleList, exclusions, &boxSize, false, radius  , 0.0);
             for ( size_t j = 0 ; j < neighborList.size(); j++) {
-                if ((((( vectorCompare(concatenatedAtomInfoVector[neighborList[j].first].chain , (referenceChains))) == 1) &&
-                     (( vectorCompare(concatenatedAtomInfoVector[neighborList[j].second].chain ,(  partnerChains))) == 1))  || 
+                if ((((( vectorCompare(concatenatedAtomInfoVector[neighborList[j].first].getChain() , (referenceChains))) == 1) &&
+                     (( vectorCompare(concatenatedAtomInfoVector[neighborList[j].second].getChain() ,(  partnerChains))) == 1))  || 
 //Use an XOR here. This means if the 'partnerChains' evaluation is later set to return 1 when partnerChains is empty, this will still work.
-                    ((( vectorCompare(concatenatedAtomInfoVector[neighborList[j].second].chain ,(referenceChains))) == 1) &&
-                     (( vectorCompare(concatenatedAtomInfoVector[neighborList[j].first].chain  ,(  partnerChains))) == 1))     //Make sure that exactly one residue is in the 'referenceChains', and the other residue is in the 'partnerChains' .. thus only the desired interface is included
+                    ((( vectorCompare(concatenatedAtomInfoVector[neighborList[j].second].getChain() ,(referenceChains))) == 1) &&
+                     (( vectorCompare(concatenatedAtomInfoVector[neighborList[j].first].getChain()  ,(  partnerChains))) == 1))     //Make sure that exactly one residue is in the 'referenceChains', and the other residue is in the 'partnerChains' .. thus only the desired interface is included
                                                                                                                          ) 
-                     && (concatenatedAtomInfoVector[neighborList[j].first].chain.compare(concatenatedAtomInfoVector[neighborList[j].second].chain) != 0 )
+                     && (concatenatedAtomInfoVector[neighborList[j].first].getChain().compare(concatenatedAtomInfoVector[neighborList[j].second].getChain()) != 0 )
                    ) // lastly,make sure the two atoms are not in the same chain.
 
                 {   
                     TwoAtomClass myTwoAtomClass(
-			(concatenatedAtomInfoVector[neighborList[j].first].chain),
-			(concatenatedAtomInfoVector[neighborList[j].first].residueID),
-			(concatenatedAtomInfoVector[neighborList[j].first].atomName),
-			(concatenatedAtomInfoVector[neighborList[j].second].chain),
-			(concatenatedAtomInfoVector[neighborList[j].second].residueID),
-			(concatenatedAtomInfoVector[neighborList[j].second].atomName)//,
+			(concatenatedAtomInfoVector[neighborList[j].first].getChain()),
+			(concatenatedAtomInfoVector[neighborList[j].first].getResidueID()),
+			(concatenatedAtomInfoVector[neighborList[j].first].getAtomName()),
+			(concatenatedAtomInfoVector[neighborList[j].second].getChain()),
+			(concatenatedAtomInfoVector[neighborList[j].second].getResidueID()),
+			(concatenatedAtomInfoVector[neighborList[j].second].getAtomName())//,
                         //(concatenatedAtomInfoVector[neighborList[j].first ].position - concatenatedAtomInfoVector[neighborList[j].second].position) // later, compute distance
                     );
                     contactingAtomInfoPairVector.push_back(myTwoAtomClass );
@@ -812,13 +889,13 @@ vector<TwoAtomClass> InterfaceContainer::retrieveCloseContactPairs(vector<MMBAto
             }
         }
         return contactingAtomInfoPairVector;  
-};
+}
 
 ConstraintClass::ConstraintClass(){
         chain1 = ""; residueID1 = ResidueID(); atomName1 = ""; 
         chain2 = ""; residueID2 = ResidueID(); atomName2 = ""; 
         constraintType = WeldToGround ; 
-        };  
+        }  
 ConstraintClass::ConstraintClass(String myChain, ResidueID inputResidueID,String myAtomName) {
         residueID1 = (inputResidueID);
         atomName1 = myAtomName;
@@ -828,7 +905,7 @@ ConstraintClass::ConstraintClass(String myChain, ResidueID inputResidueID,String
         chain2 = ""; 
         constraintType = ( WeldToGround );
         //toGround = true ;
-    }; 
+    } 
 
 ConstraintClass::ConstraintClass(String myChain, ResidueID inputResidueID,String myAtomName,String myChain2, ResidueID inputResidueID2,String myAtomName2, ConstraintType myConstraintType) {
         residueID1 = (inputResidueID);
@@ -840,7 +917,7 @@ ConstraintClass::ConstraintClass(String myChain, ResidueID inputResidueID,String
         chain2 = myChain2;
         setConstraintType(myConstraintType);
         //toGround = false;
-    };
+    }
 /*
 Array_<MobilizedBodyIndex> ConstraintClass::fetchMobilizedBodyIndexArray_(BiopolymerClassContainer myBiopolymerClassContainer,SimbodyMatterSubsystem & matter ) {
         Array_< MobilizedBodyIndex >    coordMobod(2);
@@ -887,7 +964,7 @@ void  ConstraintClass::print() const {
           //<<" to Ground: "        <<getToGround()
           <<" constraintType : " << constraintTypeString()
           <<endl;
-    };  
+    }  
 
 
 
@@ -1060,7 +1137,7 @@ bool isFixed (const String putativeFixedFloat) { // This checks that the string
 		*/
 		//return  boost::lexical_cast<String>(i);      
                 return SimTK::String(i);
-            };  
+            }  
 
 Vec3 ValidateVec3(Vec3 myVec3){
 
@@ -1197,8 +1274,8 @@ vector<String> readAndParseOnColWidth   (ifstream & inFile, int columnWidth) {
             MMBLOG_FILE_FUNC_LINE(CRITICAL, ": You have not specified enough parameters for this command."<<endl);
         } else if ( size() > correctNumFields ) {
             MMBLOG_FILE_FUNC_LINE(CRITICAL, ": You have specified too many parameters for this command."<<endl);
-        };  
-    };  
+        }  
+    }  
     void ParameterStringClass::print() const {
         MMBLOG_FILE_FUNC_LINE(DEBUG," About to print the contents of ParameterStringClass, which is in charge of storing and processing a single line from the user command file."<< endl);
         for (int i = 0 ; i < size(); i++){
@@ -1206,13 +1283,13 @@ vector<String> readAndParseOnColWidth   (ifstream & inFile, int columnWidth) {
             //std::cout<<__FILE__<<":"<<__LINE__<<" "<<i<<" >"<<stringVector[i]<<"< "<<std::endl;
         };
         //#MMBLOG_FILE_FUNC_LINE(INFO, endl);
-    };
+    }
 
     String ParameterStringClass::getString() const {
         std::stringstream ss;
         for (int i = 0 ; i < size(); i++){
             ss <<" "<<stringVector[i];
-        };
+        }
 
         return ss.str();
     }
